@@ -3,4 +3,4 @@ sparky-info for Debian
 
 <Possible notes regarding this package - if none, delete this file.>
 
- -- pavroo <pavroo@onet.eu>  Tue, 11 Nov 2025 16:56:21 +0100
+ -- pavroo <pavroo@onet.eu>  Sat, 14 Feb 2026 13:35:13 +0100
