@@ -1,10 +1,10 @@
 .\"                                      Hey, EMACS: -*- nroff -*-
-.\" (C) Copyright 2025 pavroo <pavroo@onet.eu>,
+.\" (C) Copyright 2026 pavroo <pavroo@onet.eu>,
 .\"
 .\" First parameter, NAME, should be all caps
 .\" Second parameter, SECTION, should be 1-8, maybe w/ subsection
 .\" other parameters are allowed: see man(7), man(1)
-.TH Sparky-info SECTION "November 11 2025"
+.TH Sparky-info SECTION "February 14 2026"
 .\" Please adjust this date whenever revising the manpage.
 .\"
 .\" Some roff macros, for reference:
