@@ -1,6 +1,6 @@
 % sparky-info(SECTION) | User Commands
 %
-% "November 11 2025"
+% "February 14 2026"
 
 [comment]: # The lines above form a Pandoc metadata block. They must be
 [comment]: # the first ones in the file.
